from setuptools import setup

setup(
    name='sirius_jz',
    version='0.0.21',
    author='LUIZ GUILHERME C S PADUA',
    author_email='jzguipadua@gmail.com',
    packages=['sirius_jz'],
    description='Sirius Studio for development',
    long_description='Teste de Publicação na página de Descrição',
    url='https://github.com/',
    project_urls={
        'Código fonte': 'https://github.com/',
        'Download': 'https://github.com/'
    },
    license='MIT',
    keywords='JackZafira Sirius Studio si Bifrost',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: Portuguese (Brazilian)',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Internationalization'
    ]
)
